info = {
    "name": "es",
    "date_order": "DMY",
    "january": [
        "ene",
        "enero"
    ],
    "february": [
        "feb",
        "febrero"
    ],
    "march": [
        "mar",
        "marzo"
    ],
    "april": [
        "abr",
        "abril"
    ],
    "may": [
        "may",
        "mayo"
    ],
    "june": [
        "jun",
        "junio"
    ],
    "july": [
        "jul",
        "julio"
    ],
    "august": [
        "ago",
        "agosto"
    ],
    "september": [
        "sept",
        "septiembre",
        "Setiembre",
        "Sep",
        "Set"
    ],
    "october": [
        "oct",
        "octubre"
    ],
    "november": [
        "nov",
        "noviembre"
    ],
    "december": [
        "dic",
        "diciembre"
    ],
    "monday": [
        "lun",
        "lunes",
        "Lu"
    ],
    "tuesday": [
        "mar",
        "martes"
    ],
    "wednesday": [
        "mié",
        "miércoles",
        "Mi"
    ],
    "thursday": [
        "jue",
        "jueves",
        "Ju"
    ],
    "friday": [
        "vie",
        "viernes",
        "Vi"
    ],
    "saturday": [
        "sáb",
        "sábado",
        "Sa"
    ],
    "sunday": [
        "dom",
        "domingo",
        "Do"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "a",
        "año",
        "años"
    ],
    "month": [
        "m",
        "mes",
        "meses"
    ],
    "week": [
        "sem",
        "semana",
        "semanas"
    ],
    "day": [
        "d",
        "día",
        "días"
    ],
    "hour": [
        "h",
        "hora",
        "horas"
    ],
    "minute": [
        "min",
        "minuto",
        "minutos"
    ],
    "second": [
        "s",
        "segundo",
        "segundos"
    ],
    "relative-type": {
        "0 day ago": [
            "hoy"
        ],
        "0 hour ago": [
            "esta hora"
        ],
        "0 minute ago": [
            "este minuto"
        ],
        "0 month ago": [
            "este mes"
        ],
        "0 second ago": [
            "ahora"
        ],
        "0 week ago": [
            "esta semana"
        ],
        "0 year ago": [
            "este año"
        ],
        "1 day ago": [
            "ayer"
        ],
        "1 month ago": [
            "el mes pasado"
        ],
        "1 week ago": [
            "la semana pasada"
        ],
        "1 year ago": [
            "el año pasado"
        ],
        "in 1 day": [
            "mañana"
        ],
        "in 1 month": [
            "el próximo mes"
        ],
        "in 1 week": [
            "la próxima semana"
        ],
        "in 1 year": [
            "el próximo año"
        ],
        "2 day ago": [
            "anteayer"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "hace (\\d+[.,]?\\d*) día",
            "hace (\\d+[.,]?\\d*) días"
        ],
        "\\1 hour ago": [
            "hace (\\d+[.,]?\\d*) h",
            "hace (\\d+[.,]?\\d*) hora",
            "hace (\\d+[.,]?\\d*) horas"
        ],
        "\\1 minute ago": [
            "hace (\\d+[.,]?\\d*) min",
            "hace (\\d+[.,]?\\d*) minuto",
            "hace (\\d+[.,]?\\d*) minutos"
        ],
        "\\1 month ago": [
            "hace (\\d+[.,]?\\d*) m",
            "hace (\\d+[.,]?\\d*) mes",
            "hace (\\d+[.,]?\\d*) meses"
        ],
        "\\1 second ago": [
            "hace (\\d+[.,]?\\d*) s",
            "hace (\\d+[.,]?\\d*) segundo",
            "hace (\\d+[.,]?\\d*) segundos"
        ],
        "\\1 week ago": [
            "hace (\\d+[.,]?\\d*) sem",
            "hace (\\d+[.,]?\\d*) semana",
            "hace (\\d+[.,]?\\d*) semanas"
        ],
        "\\1 year ago": [
            "hace (\\d+[.,]?\\d*) a",
            "hace (\\d+[.,]?\\d*) año",
            "hace (\\d+[.,]?\\d*) años"
        ],
        "in \\1 day": [
            "dentro de (\\d+[.,]?\\d*) día",
            "dentro de (\\d+[.,]?\\d*) días"
        ],
        "in \\1 hour": [
            "dentro de (\\d+[.,]?\\d*) h",
            "dentro de (\\d+[.,]?\\d*) hora",
            "dentro de (\\d+[.,]?\\d*) horas"
        ],
        "in \\1 minute": [
            "dentro de (\\d+[.,]?\\d*) min",
            "dentro de (\\d+[.,]?\\d*) minuto",
            "dentro de (\\d+[.,]?\\d*) minutos"
        ],
        "in \\1 month": [
            "dentro de (\\d+[.,]?\\d*) m",
            "dentro de (\\d+[.,]?\\d*) mes",
            "dentro de (\\d+[.,]?\\d*) meses"
        ],
        "in \\1 second": [
            "dentro de (\\d+[.,]?\\d*) s",
            "dentro de (\\d+[.,]?\\d*) segundo",
            "dentro de (\\d+[.,]?\\d*) segundos"
        ],
        "in \\1 week": [
            "dentro de (\\d+[.,]?\\d*) sem",
            "dentro de (\\d+[.,]?\\d*) semana",
            "dentro de (\\d+[.,]?\\d*) semanas"
        ],
        "in \\1 year": [
            "dentro de (\\d+[.,]?\\d*) a",
            "dentro de (\\d+[.,]?\\d*) año",
            "dentro de (\\d+[.,]?\\d*) años"
        ]
    },
    "locale_specific": {
        "es-419": {
            "name": "es-419",
            "september": [
                "sep"
            ]
        },
        "es-AR": {
            "name": "es-AR",
            "september": [
                "sep"
            ],
            "second": [
                "seg"
            ],
            "relative-type-regex": {
                "\\1 second ago": [
                    "hace (\\d+[.,]?\\d*) seg"
                ],
                "in \\1 second": [
                    "dentro de (\\d+[.,]?\\d*) seg"
                ]
            }
        },
        "es-BO": {
            "name": "es-BO",
            "september": [
                "sep"
            ]
        },
        "es-BR": {
            "name": "es-BR",
            "september": [
                "sep"
            ]
        },
        "es-BZ": {
            "name": "es-BZ",
            "september": [
                "sep"
            ]
        },
        "es-CL": {
            "name": "es-CL",
            "september": [
                "sep"
            ]
        },
        "es-CO": {
            "name": "es-CO",
            "september": [
                "sep"
            ]
        },
        "es-CR": {
            "name": "es-CR",
            "september": [
                "sep"
            ]
        },
        "es-CU": {
            "name": "es-CU",
            "september": [
                "sep"
            ]
        },
        "es-DO": {
            "name": "es-DO",
            "september": [
                "sep"
            ]
        },
        "es-EA": {
            "name": "es-EA"
        },
        "es-EC": {
            "name": "es-EC",
            "september": [
                "sep"
            ]
        },
        "es-GQ": {
            "name": "es-GQ"
        },
        "es-GT": {
            "name": "es-GT",
            "september": [
                "sep"
            ]
        },
        "es-HN": {
            "name": "es-HN",
            "september": [
                "sep"
            ]
        },
        "es-IC": {
            "name": "es-IC"
        },
        "es-MX": {
            "name": "es-MX",
            "september": [
                "sep"
            ],
            "relative-type": {
                "in 1 month": [
                    "el mes próximo"
                ],
                "in 1 week": [
                    "la semana próxima"
                ],
                "in 1 year": [
                    "el año próximo"
                ]
            },
            "relative-type-regex": {
                "in \\1 day": [
                    "en (\\d+[.,]?\\d*) día",
                    "en (\\d+[.,]?\\d*) días"
                ],
                "in \\1 hour": [
                    "en (\\d+[.,]?\\d*) h",
                    "en (\\d+[.,]?\\d*) n"
                ],
                "in \\1 minute": [
                    "en (\\d+[.,]?\\d*) min"
                ],
                "in \\1 month": [
                    "en (\\d+[.,]?\\d*) m",
                    "en (\\d+[.,]?\\d*) mes",
                    "en (\\d+[.,]?\\d*) meses"
                ],
                "in \\1 second": [
                    "en (\\d+[.,]?\\d*) s"
                ],
                "in \\1 week": [
                    "en (\\d+[.,]?\\d*) sem"
                ],
                "in \\1 year": [
                    "en (\\d+[.,]?\\d*) a"
                ]
            }
        },
        "es-NI": {
            "name": "es-NI",
            "september": [
                "sep"
            ]
        },
        "es-PA": {
            "name": "es-PA",
            "date_order": "MDY",
            "september": [
                "sep"
            ]
        },
        "es-PE": {
            "name": "es-PE",
            "september": [
                "set",
                "setiembre"
            ]
        },
        "es-PH": {
            "name": "es-PH"
        },
        "es-PR": {
            "name": "es-PR",
            "date_order": "MDY",
            "september": [
                "sep"
            ]
        },
        "es-PY": {
            "name": "es-PY",
            "second": [
                "seg"
            ],
            "relative-type-regex": {
                "\\1 second ago": [
                    "hace (\\d+[.,]?\\d*) seg"
                ],
                "in \\1 second": [
                    "dentro de (\\d+[.,]?\\d*) seg"
                ]
            }
        },
        "es-SV": {
            "name": "es-SV",
            "september": [
                "sep"
            ]
        },
        "es-US": {
            "name": "es-US",
            "september": [
                "sep"
            ]
        },
        "es-UY": {
            "name": "es-UY",
            "september": [
                "set",
                "setiembre"
            ]
        },
        "es-VE": {
            "name": "es-VE"
        }
    },
    "skip": [
        "a las",
        "cerca",
        "de",
        "del",
        "en",
        "y",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "pertain": [
        "de",
        "del"
    ],
    "sentence_splitter_group": 2,
    "ago": [
        "hace"
    ],
    "in": [
        "en"
    ],
    "simplifications": [
        {
            "una": "1"
        },
        {
            "un": "1"
        }
    ]
}



info = {
    "name": "ii",
    "date_order": "YMD",
    "january": [
        "ꋍꆪ"
    ],
    "february": [
        "ꑍꆪ"
    ],
    "march": [
        "ꌕꆪ"
    ],
    "april": [
        "ꇖꆪ"
    ],
    "may": [
        "ꉬꆪ"
    ],
    "june": [
        "ꃘꆪ"
    ],
    "july": [
        "ꏃꆪ"
    ],
    "august": [
        "ꉆꆪ"
    ],
    "september": [
        "ꈬꆪ"
    ],
    "october": [
        "ꊰꆪ"
    ],
    "november": [
        "ꊰꊪꆪ"
    ],
    "december": [
        "ꊰꑋꆪ"
    ],
    "monday": [
        "ꆏꊂꋍ",
        "ꆏꋍ"
    ],
    "tuesday": [
        "ꆏꊂꑍ",
        "ꆏꑍ"
    ],
    "wednesday": [
        "ꆏꊂꌕ",
        "ꆏꌕ"
    ],
    "thursday": [
        "ꆏꇖ",
        "ꆏꊂꇖ"
    ],
    "friday": [
        "ꆏꉬ",
        "ꆏꊂꉬ"
    ],
    "saturday": [
        "ꆏꃘ",
        "ꆏꊂꃘ"
    ],
    "sunday": [
        "ꑭꆏ",
        "ꑭꆏꑍ"
    ],
    "am": [
        "ꎸꄑ"
    ],
    "pm": [
        "ꁯꋒ"
    ],
    "year": [
        "ꈎ"
    ],
    "month": [
        "ꆪ"
    ],
    "week": [
        "ꑭꆏ"
    ],
    "day": [
        "ꑍ"
    ],
    "hour": [
        "ꄮꈉ"
    ],
    "minute": [
        "ꃏ"
    ],
    "second": [
        "ꇙ"
    ],
    "relative-type": {
        "0 day ago": [
            "ꀃꑍ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ꀋꅔꉈ"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ꃆꏂꑍ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "cs",
    "date_order": "DMY",
    "january": [
        "led",
        "leden",
        "ledna"
    ],
    "february": [
        "úno",
        "únor",
        "února",
        "únr"
    ],
    "march": [
        "bře",
        "březen",
        "března"
    ],
    "april": [
        "dub",
        "duben",
        "dubna"
    ],
    "may": [
        "kvě",
        "květen",
        "května"
    ],
    "june": [
        "červen",
        "června",
        "čvn",
        "Čer"
    ],
    "july": [
        "července",
        "červenec",
        "čvc",
        "Črc",
        "črv"
    ],
    "august": [
        "srp",
        "srpen",
        "srpna"
    ],
    "september": [
        "zář",
        "září"
    ],
    "october": [
        "říj",
        "říjen",
        "října"
    ],
    "november": [
        "lis",
        "listopad",
        "listopadu"
    ],
    "december": [
        "pro",
        "prosince",
        "prosinec"
    ],
    "monday": [
        "po",
        "pondělí",
        "Pon"
    ],
    "tuesday": [
        "út",
        "úterý",
        "Úte"
    ],
    "wednesday": [
        "st",
        "středa",
        "Stř",
        "Středu"
    ],
    "thursday": [
        "čt",
        "čtvrtek",
        "Čtv"
    ],
    "friday": [
        "pá",
        "pátek",
        "Pát"
    ],
    "saturday": [
        "so",
        "sobota",
        "Sob",
        "Sobotu"
    ],
    "sunday": [
        "ne",
        "neděle",
        "Ned",
        "Neděli"
    ],
    "am": [
        "dop"
    ],
    "pm": [
        "odp"
    ],
    "year": [
        "r",
        "rok",
        "roků",
        "roky"
    ],
    "month": [
        "měs",
        "měsíc",
        "měsíců",
        "měsíce",
        "měsícem"
    ],
    "week": [
        "týd",
        "týden",
        "týdnů",
        "týdny",
        "týdnem"
    ],
    "day": [
        "den",
        "dnů",
        "dny"
    ],
    "hour": [
        "h",
        "hodina",
        "hodin",
        "hodiny",
        "hodinou",
        "hodinu",
        "hodinami"
    ],
    "minute": [
        "min",
        "minuta",
        "minut",
        "minutami",
        "minuty"
    ],
    "second": [
        "s",
        "sekunda",
        "sekundy",
        "sekund",
        "vteřina",
        "vteřin",
        "vteřiny"
    ],
    "relative-type": {
        "0 day ago": [
            "dnes"
        ],
        "0 hour ago": [
            "tuto hodinu"
        ],
        "0 minute ago": [
            "tuto minutu"
        ],
        "0 month ago": [
            "tento měsíc"
        ],
        "0 second ago": [
            "nyní"
        ],
        "0 week ago": [
            "tento týd",
            "tento týden"
        ],
        "0 year ago": [
            "tento rok"
        ],
        "1 day ago": [
            "včera"
        ],
        "1 month ago": [
            "minulý měsíc"
        ],
        "1 week ago": [
            "minulý týd",
            "minulý týden"
        ],
        "1 year ago": [
            "minulý rok"
        ],
        "in 1 day": [
            "zítra"
        ],
        "in 1 month": [
            "příští měsíc"
        ],
        "in 1 week": [
            "příští týd",
            "příští týden"
        ],
        "in 1 year": [
            "příští rok"
        ],
        "2 day ago": [
            "předevčírem"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "před (\\d+[.,]?\\d*) dnem",
            "před (\\d+[.,]?\\d*) dny"
        ],
        "\\1 hour ago": [
            "před (\\d+[.,]?\\d*) h",
            "před (\\d+[.,]?\\d*) hodinami",
            "před (\\d+[.,]?\\d*) hodinou"
        ],
        "\\1 minute ago": [
            "před (\\d+[.,]?\\d*) min",
            "před (\\d+[.,]?\\d*) minutami",
            "před (\\d+[.,]?\\d*) minutou"
        ],
        "\\1 month ago": [
            "před (\\d+[.,]?\\d*) měs",
            "před (\\d+[.,]?\\d*) měsícem",
            "před (\\d+[.,]?\\d*) měsíci"
        ],
        "\\1 second ago": [
            "před (\\d+[.,]?\\d*) s",
            "před (\\d+[.,]?\\d*) sekundami",
            "před (\\d+[.,]?\\d*) sekundou"
        ],
        "\\1 week ago": [
            "před (\\d+[.,]?\\d*) týd",
            "před (\\d+[.,]?\\d*) týdnem",
            "před (\\d+[.,]?\\d*) týdny"
        ],
        "\\1 year ago": [
            "před (\\d+[.,]?\\d*) l",
            "před (\\d+[.,]?\\d*) lety",
            "před (\\d+[.,]?\\d*) r",
            "před (\\d+[.,]?\\d*) rokem"
        ],
        "in \\1 day": [
            "za (\\d+[.,]?\\d*) den",
            "za (\\d+[.,]?\\d*) dní"
        ],
        "in \\1 hour": [
            "za (\\d+[.,]?\\d*) h",
            "za (\\d+[.,]?\\d*) hodin",
            "za (\\d+[.,]?\\d*) hodinu"
        ],
        "in \\1 minute": [
            "za (\\d+[.,]?\\d*) min",
            "za (\\d+[.,]?\\d*) minut",
            "za (\\d+[.,]?\\d*) minutu"
        ],
        "in \\1 month": [
            "za (\\d+[.,]?\\d*) měs",
            "za (\\d+[.,]?\\d*) měsíc",
            "za (\\d+[.,]?\\d*) měsíců"
        ],
        "in \\1 second": [
            "za (\\d+[.,]?\\d*) s",
            "za (\\d+[.,]?\\d*) sekund",
            "za (\\d+[.,]?\\d*) sekundu"
        ],
        "in \\1 week": [
            "za (\\d+[.,]?\\d*) týd",
            "za (\\d+[.,]?\\d*) týden",
            "za (\\d+[.,]?\\d*) týdnů"
        ],
        "in \\1 year": [
            "za (\\d+[.,]?\\d*) l",
            "za (\\d+[.,]?\\d*) let",
            "za (\\d+[.,]?\\d*) r",
            "za (\\d+[.,]?\\d*) rok"
        ]
    },
    "locale_specific": {},
    "skip": [
        "přibližně",
        "v",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "před"
    ],
    "in": [
        "ve",
        "v"
    ],
    "simplifications": [
        {
            "teď": "0 sekunda"
        }
    ]
}



info = {
    "name": "sg",
    "date_order": "DMY",
    "january": [
        "nye",
        "nyenye"
    ],
    "february": [
        "ful",
        "fulundïgi"
    ],
    "march": [
        "mbä",
        "mbängü"
    ],
    "april": [
        "ngu",
        "ngubùe"
    ],
    "may": [
        "bêl",
        "bêläwü"
    ],
    "june": [
        "fön",
        "föndo"
    ],
    "july": [
        "len",
        "lengua"
    ],
    "august": [
        "kük",
        "kükürü"
    ],
    "september": [
        "mvu",
        "mvuka"
    ],
    "october": [
        "ngb",
        "ngberere"
    ],
    "november": [
        "nab",
        "nabändüru"
    ],
    "december": [
        "kak",
        "kakauka"
    ],
    "monday": [
        "bk2",
        "bïkua-ûse"
    ],
    "tuesday": [
        "bk3",
        "bïkua-ptâ"
    ],
    "wednesday": [
        "bk4",
        "bïkua-usïö"
    ],
    "thursday": [
        "bk5",
        "bïkua-okü"
    ],
    "friday": [
        "lâp",
        "lâpôsö"
    ],
    "saturday": [
        "lây",
        "lâyenga"
    ],
    "sunday": [
        "bikua-ôko",
        "bk1"
    ],
    "am": [
        "nd"
    ],
    "pm": [
        "lk"
    ],
    "year": [
        "ngû"
    ],
    "month": [
        "nze"
    ],
    "week": [
        "dimâsi"
    ],
    "day": [
        "lâ"
    ],
    "hour": [
        "ngbonga"
    ],
    "minute": [
        "ndurü ngbonga"
    ],
    "second": [
        "nzîna ngbonga"
    ],
    "relative-type": {
        "0 day ago": [
            "lâsô"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "bîrï"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kêkerêke"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



from . import CalendarBase
from dateparser.calendars.jalali_parser import jalali_parser


class JalaliCalendar(CalendarBase):
    """Calendar class for Jalali calendar."""

    parser = jalali_parser



import json
import os
from collections import OrderedDict

import regex as re

from dateparser_scripts.utils import get_raw_data
from parsel import Selector
import requests

os.chdir(os.path.dirname(os.path.abspath(__file__)))

# Languages with insufficient translation data are excluded
avoid_languages = {'cu', 'kkj', 'nds', 'prg', 'tk', 'vai', 'vai-Latn', 'vai-Vaii', 'vo'}


def _get_language_locale_dict():
    cldr_dates_full_dir = "../raw_data/cldr_dates_full/main/"
    available_locale_names = os.listdir(cldr_dates_full_dir)
    available_language_names = [shortname for shortname in available_locale_names
                                if not re.search(r'-[A-Z0-9]+$', shortname)]
    available_language_names.remove('root')
    language_locale_dict = {}
    for language_name in available_language_names:
        language_locale_dict[language_name] = []
        for locale_name in available_locale_names:
            if re.match(language_name + '-[A-Z0-9]+$', locale_name):
                language_locale_dict[language_name].append(locale_name)

    for language in avoid_languages:
        if language in language_locale_dict:
            del language_locale_dict[language]
    return language_locale_dict


def _get_language_order(language_locale_dict):
    def get_most_common_locales():
        # Order from https://w3techs.com/technologies/overview/content_language
        # Last updated on 03.10.2022
        old_common_locales = ['en',
                               'ru',
                               'es',
                               'de',
                               'tr',
                               'fr',
                               'fa',
                               'ja',
                               'zh',
                               'vi',
                               'it',
                               'nl',
                               'pt',
                               'ar',
                               'pl',
                               'id',
                               'ko',
                               'uk',
                               'th',
                               'he',
                               'cs',
                               'sv',
                               'ro',
                               'el',
                               'da',
                               'hu',
                               'fi',
                               'sr',
                               'sk',
                               'bg',
                               'nb',
                               'hr',
                               'lt',
                               'no',
                               'hi',
                               'sl',
                               'ca',
                               'et']

        response = requests.get('https://w3techs.com/technologies/overview/content_language')
        sel = Selector(text=response.text)
        if response.ok:
            try:
                bars = sel.xpath("//table[@class='bars']//a/@href").getall()
                if not bars:
                    raise ValueError("No bars found")
                new_most_common_locales = [i.replace('https://w3techs.com/technologies/details/cl', '').strip('-') for i in bars]
                if new_most_common_locales[0] != 'en':
                    raise ValueError("English is not the first language")
            except Exception as e:
                print(e)
                print("The website could have changed, please update the code")
                return old_common_locales
        else:
            return old_common_locales
        return new_most_common_locales

    territory_info_file = "../raw_data/cldr_core/supplemental/territoryInfo.json"
    with open(territory_info_file) as f:
        territory_content = json.load(f)
    territory_info_data = territory_content["supplemental"]["territoryInfo"]

    language_population_dict = {}
    for territory in territory_info_data:
        population = int(territory_info_data[territory]["_population"])
        try:
            lang_dict = territory_info_data[territory]["languagePopulation"]
            for language in lang_dict:
                language_population = float(lang_dict[language]["_populationPercent"]) * population
                if language in language_population_dict:
                    language_population_dict[language] += language_population
                else:
                    language_population_dict[language] = language_population
        except Exception:
            pass

    most_common_locales = get_most_common_locales()
    language_order_with_duplicates = (
        most_common_locales
        + sorted(
            language_population_dict.keys(),
            key=lambda x: (language_population_dict[x], x), reverse=True
        )
    )
    language_order = sorted(
        set(language_order_with_duplicates),
        key=lambda x: language_order_with_duplicates.index(x)
    )

    for index in range(0, len(language_order)):
        language_order[index] = re.sub(r'_', r'-', language_order[index])

    cldr_languages = language_locale_dict.keys()
    supplementary_date_directory = "../dateparser_data/supplementary_language_data/date_translation_data"
    supplementary_languages = [x[:-5] for x in os.listdir(supplementary_date_directory)]
    available_languages = set(cldr_languages).union(set(supplementary_languages))
    language_order = [shortname for shortname in language_order if shortname in available_languages]
    absent_languages = set(available_languages) - set(language_order)
    remaining_languages = []
    for language in absent_languages:
        parent_language = re.sub(r'-\w+', '', language)
        if parent_language in language_order:
            language_order.insert(language_order.index(parent_language) + 1, language)
        else:
            remaining_languages.append(language)
    language_order = language_order + sorted(remaining_languages)
    language_order = list(map(str, language_order))
    return language_order


def generate_language_map(language_order):
    data = {}
    for lang in sorted(language_order):
        if '-' not in lang:
            data[lang] = [lang]
        else:
            data[lang.split('-')[0]].append(lang)
    return data


def main():
    get_raw_data()
    language_locale_dict = _get_language_locale_dict()
    language_order = _get_language_order(language_locale_dict)

    parent_directory = "../dateparser/data/"
    filename = "../dateparser/data/languages_info.py"
    if not os.path.isdir(parent_directory):
        os.mkdir(parent_directory)
    language_order_string = 'language_order = ' + json.dumps(
        language_order, separators=(',', ': '), indent=4
    )

    complete_language_locale_dict = OrderedDict()
    for key in language_order:
        if key in language_locale_dict.keys():
            complete_language_locale_dict[key] = sorted(language_locale_dict[key])
        else:
            complete_language_locale_dict[key] = []

    language_locale_dict_string = 'language_locale_dict = ' + json.dumps(
        complete_language_locale_dict, separators=(',', ': '), indent=4
    )
    language_map_data = generate_language_map(language_order)
    language_map_data_string = 'language_map = ' + json.dumps(
        language_map_data, separators=(',', ': '), indent=4
    )

    languages_info_string = language_order_string + '\n\n' + language_map_data_string + '\n\n' + language_locale_dict_string + '\n'
    with open(filename, 'w') as f:
        f.write(languages_info_string)


if __name__ == '__main__':
    main()



info = {
    "name": "yo",
    "date_order": "DMY",
    "january": [
        "oṣù ṣẹ́rẹ́",
        "ṣẹ́rẹ́"
    ],
    "february": [
        "oṣù èrèlè",
        "èrèlè"
    ],
    "march": [
        "oṣù ẹrẹ̀nà",
        "ẹrẹ̀nà"
    ],
    "april": [
        "oṣù ìgbé",
        "ìgbé"
    ],
    "may": [
        "oṣù ẹ̀bibi",
        "ẹ̀bibi"
    ],
    "june": [
        "oṣù òkúdu",
        "òkúdu"
    ],
    "july": [
        "agẹmọ",
        "oṣù agẹmọ"
    ],
    "august": [
        "oṣù ògún",
        "ògún"
    ],
    "september": [
        "owewe",
        "oṣù owewe"
    ],
    "october": [
        "oṣù ọ̀wàrà",
        "ọ̀wàrà"
    ],
    "november": [
        "bélú",
        "oṣù bélú"
    ],
    "december": [
        "oṣù ọ̀pẹ̀",
        "ọ̀pẹ̀"
    ],
    "monday": [
        "ajé",
        "ọjọ́ ajé"
    ],
    "tuesday": [
        "ìsẹ́gun",
        "ọjọ́ ìsẹ́gun"
    ],
    "wednesday": [
        "ọjọ́rú"
    ],
    "thursday": [
        "ọjọ́bọ"
    ],
    "friday": [
        "ẹtì",
        "ọjọ́ ẹtì"
    ],
    "saturday": [
        "àbámẹ́ta",
        "ọjọ́ àbámẹ́ta"
    ],
    "sunday": [
        "àìkú",
        "ọjọ́ àìkú"
    ],
    "am": [
        "àárọ̀"
    ],
    "pm": [
        "ọ̀sán"
    ],
    "year": [
        "ọdún"
    ],
    "month": [
        "osù"
    ],
    "week": [
        "ọ̀sè"
    ],
    "day": [
        "ọjọ́"
    ],
    "hour": [
        "wákàtí"
    ],
    "minute": [
        "ìsẹ́jú"
    ],
    "second": [
        "ìsẹ́jú ààyá"
    ],
    "relative-type": {
        "0 day ago": [
            "òní"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "àná"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ọ̀la"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "yo-BJ": {
            "name": "yo-BJ",
            "january": [
                "oshù shɛ́rɛ́",
                "shɛ́rɛ́"
            ],
            "february": [
                "oshù èrèlè"
            ],
            "march": [
                "oshù ɛrɛ̀nà",
                "ɛrɛ̀nà"
            ],
            "april": [
                "oshù ìgbé"
            ],
            "may": [
                "oshù ɛ̀bibi",
                "ɛ̀bibi"
            ],
            "june": [
                "oshù òkúdu"
            ],
            "july": [
                "agɛmɔ",
                "oshù agɛmɔ"
            ],
            "august": [
                "oshù ògún"
            ],
            "september": [
                "oshù owewe"
            ],
            "october": [
                "oshù ɔ̀wàrà",
                "ɔ̀wàrà"
            ],
            "november": [
                "oshù bélú"
            ],
            "december": [
                "oshù ɔ̀pɛ̀",
                "ɔ̀pɛ̀"
            ],
            "monday": [
                "ɔjɔ́ ajé"
            ],
            "tuesday": [
                "ìsɛ́gun",
                "ɔjɔ́ ìsɛ́gun"
            ],
            "wednesday": [
                "ɔjɔ́rú"
            ],
            "thursday": [
                "ɔjɔ́bɔ"
            ],
            "friday": [
                "ɔjɔ́ ɛtì",
                "ɛtì"
            ],
            "saturday": [
                "àbámɛ́ta",
                "ɔjɔ́ àbámɛ́ta"
            ],
            "sunday": [
                "ɔjɔ́ àìkú"
            ],
            "am": [
                "àárɔ̀"
            ],
            "pm": [
                "ɔ̀sán"
            ],
            "year": [
                "ɔdún"
            ],
            "week": [
                "ɔ̀sè"
            ],
            "day": [
                "ɔjɔ́"
            ],
            "minute": [
                "ìsɛ́jú"
            ],
            "second": [
                "ìsɛ́jú ààyá"
            ],
            "relative-type": {
                "in 1 day": [
                    "ɔ̀la"
                ]
            }
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "id",
    "date_order": "DMY",
    "january": [
        "jan",
        "januari"
    ],
    "february": [
        "feb",
        "februari"
    ],
    "march": [
        "mar",
        "maret"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "juli"
    ],
    "august": [
        "agt",
        "agustus",
        "Agu"
    ],
    "september": [
        "sep",
        "september",
        "Sept"
    ],
    "october": [
        "okt",
        "oktober"
    ],
    "november": [
        "nov",
        "november"
    ],
    "december": [
        "des",
        "desember"
    ],
    "monday": [
        "sen",
        "senin"
    ],
    "tuesday": [
        "sel",
        "selasa"
    ],
    "wednesday": [
        "rab",
        "rabu"
    ],
    "thursday": [
        "kam",
        "kamis"
    ],
    "friday": [
        "jum",
        "jumat"
    ],
    "saturday": [
        "sab",
        "sabtu"
    ],
    "sunday": [
        "min",
        "minggu",
        "Ahad"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "tahun",
        "thn"
    ],
    "month": [
        "bln",
        "bulan"
    ],
    "week": [
        "mgg",
        "minggu"
    ],
    "day": [
        "h",
        "hari"
    ],
    "hour": [
        "j",
        "jam"
    ],
    "minute": [
        "m",
        "menit",
        "mnt"
    ],
    "second": [
        "d",
        "detik",
        "dtk"
    ],
    "relative-type": {
        "0 day ago": [
            "hari ini"
        ],
        "0 hour ago": [
            "jam ini"
        ],
        "0 minute ago": [
            "menit ini"
        ],
        "0 month ago": [
            "bulan ini"
        ],
        "0 second ago": [
            "sekarang",
            "baru saja"
        ],
        "0 week ago": [
            "minggu ini"
        ],
        "0 year ago": [
            "tahun ini"
        ],
        "1 day ago": [
            "kemarin"
        ],
        "1 month ago": [
            "bulan lalu"
        ],
        "1 week ago": [
            "minggu lalu"
        ],
        "1 year ago": [
            "tahun lalu"
        ],
        "in 1 day": [
            "besok"
        ],
        "in 1 month": [
            "bulan berikutnya"
        ],
        "in 1 week": [
            "minggu depan"
        ],
        "in 1 year": [
            "tahun depan"
        ],
        "1 year": [
            "setahun"
        ],
        "1 month": [
            "sebulan"
        ],
        "1 week": [
            "seminggu"
        ],
        "2 day ago": [
            "kemarin lusa"
        ],
        "1 day": [
            "sehari"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) h lalu",
            "(\\d+[.,]?\\d*) hari yang lalu"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) jam lalu",
            "(\\d+[.,]?\\d*) jam yang lalu"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) menit yang lalu",
            "(\\d+[.,]?\\d*) mnt lalu"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) bln lalu",
            "(\\d+[.,]?\\d*) bulan yang lalu",
            "(\\d+[.,]?\\d*) bulan lalu"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) detik yang lalu",
            "(\\d+[.,]?\\d*) dtk lalu"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) mgg lalu",
            "(\\d+[.,]?\\d*) minggu yang lalu",
            "(\\d+[.,]?\\d*) minggu lalu"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) tahun yang lalu",
            "(\\d+[.,]?\\d*) thn lalu",
            "(\\d+[.,]?\\d*) tahun lalu"
        ],
        "in \\1 day": [
            "dalam (\\d+[.,]?\\d*) h",
            "dalam (\\d+[.,]?\\d*) hari"
        ],
        "in \\1 hour": [
            "dalam (\\d+[.,]?\\d*) jam"
        ],
        "in \\1 minute": [
            "dalam (\\d+[.,]?\\d*) menit",
            "dlm (\\d+[.,]?\\d*) mnt"
        ],
        "in \\1 month": [
            "dalam (\\d+[.,]?\\d*) bulan",
            "dlm (\\d+[.,]?\\d*) bln"
        ],
        "in \\1 second": [
            "dalam (\\d+[.,]?\\d*) detik",
            "dlm (\\d+[.,]?\\d*) dtk"
        ],
        "in \\1 week": [
            "dalam (\\d+[.,]?\\d*) minggu",
            "dlm (\\d+[.,]?\\d*) mgg"
        ],
        "in \\1 year": [
            "dalam (\\d+[.,]?\\d*) tahun",
            "dlm (\\d+[.,]?\\d*) thn"
        ],
        "\\1 week": [
            "(\\d+[.,]?\\d*) minggu"
        ],
        "sunday": [
            "minggu"
        ]
    },
    "locale_specific": {},
    "skip": [
        "pukul",
        "tanggal",
        "yang",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "lalu"
    ],
    "in": [
        "dalam"
    ]
}



info = {
    "name": "ru",
    "date_order": "DMY",
    "january": [
        "янв",
        "январь",
        "января"
    ],
    "february": [
        "февр",
        "февраль",
        "февраля",
        "Фев"
    ],
    "march": [
        "мар",
        "март",
        "марта"
    ],
    "april": [
        "апр",
        "апрель",
        "апреля"
    ],
    "may": [
        "май",
        "мая"
    ],
    "june": [
        "июн",
        "июнь",
        "июня"
    ],
    "july": [
        "июл",
        "июль",
        "июля"
    ],
    "august": [
        "авг",
        "август",
        "августа"
    ],
    "september": [
        "сент",
        "сентябрь",
        "сентября",
        "Сен"
    ],
    "october": [
        "окт",
        "октябрь",
        "октября"
    ],
    "november": [
        "нояб",
        "ноябрь",
        "ноября",
        "Ноя"
    ],
    "december": [
        "дек",
        "декабрь",
        "декабря"
    ],
    "monday": [
        "пн",
        "понедельник",
        "пнд"
    ],
    "tuesday": [
        "вт",
        "вторник",
        "втр"
    ],
    "wednesday": [
        "ср",
        "среда",
        "срд",
        "среду"
    ],
    "thursday": [
        "четверг",
        "чт",
        "чтв"
    ],
    "friday": [
        "пт",
        "пятница",
        "птн",
        "пятницу"
    ],
    "saturday": [
        "сб",
        "суббота",
        "сбт",
        "субботу"
    ],
    "sunday": [
        "воскресенье",
        "вс",
        "воскресение",
        "вск"
    ],
    "am": [
        "дп"
    ],
    "pm": [
        "пп"
    ],
    "year": [
        "г",
        "год",
        "года",
        "году",
        "лет"
    ],
    "month": [
        "мес",
        "месяц",
        "месяца",
        "месяцев"
    ],
    "week": [
        "нед",
        "неделя",
        "недели",
        "недель",
        "неделю"
    ],
    "day": [
        "день",
        "дн",
        "дня",
        "дней",
        "сутки",
        "суток"
    ],
    "hour": [
        "ч",
        "час",
        "часа",
        "часов"
    ],
    "minute": [
        "мин",
        "минута",
        "минуты",
        "минут",
        "минуту"
    ],
    "second": [
        "с",
        "сек",
        "секунда",
        "секунды",
        "секунд",
        "секунду"
    ],
    "relative-type": {
        "0 day ago": [
            "сегодня"
        ],
        "0 hour ago": [
            "в этом часе"
        ],
        "0 minute ago": [
            "в эту минуту"
        ],
        "0 month ago": [
            "в этом месяце"
        ],
        "0 second ago": [
            "сейчас"
        ],
        "0 week ago": [
            "на этой неделе"
        ],
        "0 year ago": [
            "в этом году"
        ],
        "1 day ago": [
            "вчера"
        ],
        "1 month ago": [
            "в прошлом месяце"
        ],
        "1 week ago": [
            "на прошлой неделе"
        ],
        "1 year ago": [
            "в прошлом году"
        ],
        "in 1 day": [
            "завтра"
        ],
        "in 1 month": [
            "в следующем месяце"
        ],
        "in 1 week": [
            "на следующей неделе"
        ],
        "in 1 year": [
            "в следующем году"
        ],
        "2 day ago": [
            "позавчера"
        ],
        "in 2 day": [
            "послезавтра"
        ],
        "in 3 day": [
            "послепослезавтра"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) д назад",
            "(\\d+[.,]?\\d*) день назад",
            "(\\d+[.,]?\\d*) дн назад",
            "(\\d+[.,]?\\d*) дня назад"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) ч назад",
            "(\\d+[.,]?\\d*) час назад",
            "(\\d+[.,]?\\d*) часа назад"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) мин назад",
            "(\\d+[.,]?\\d*) минуту назад",
            "(\\d+[.,]?\\d*) минуты назад"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) мес назад",
            "(\\d+[.,]?\\d*) месяц назад",
            "(\\d+[.,]?\\d*) месяца назад"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) сек назад",
            "(\\d+[.,]?\\d*) секунду назад",
            "(\\d+[.,]?\\d*) секунды назад"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) нед назад",
            "(\\d+[.,]?\\d*) недели назад",
            "(\\d+[.,]?\\d*) неделю назад"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) г назад",
            "(\\d+[.,]?\\d*) год назад",
            "(\\d+[.,]?\\d*) года назад"
        ],
        "in \\1 day": [
            "через (\\d+[.,]?\\d*) д",
            "через (\\d+[.,]?\\d*) день",
            "через (\\d+[.,]?\\d*) дн",
            "через (\\d+[.,]?\\d*) дня"
        ],
        "in \\1 hour": [
            "через (\\d+[.,]?\\d*) ч",
            "через (\\d+[.,]?\\d*) час",
            "через (\\d+[.,]?\\d*) часа"
        ],
        "in \\1 minute": [
            "через (\\d+[.,]?\\d*) мин",
            "через (\\d+[.,]?\\d*) минуту",
            "через (\\d+[.,]?\\d*) минуты"
        ],
        "in \\1 month": [
            "через (\\d+[.,]?\\d*) мес",
            "через (\\d+[.,]?\\d*) месяц",
            "через (\\d+[.,]?\\d*) месяца"
        ],
        "in \\1 second": [
            "через (\\d+[.,]?\\d*) сек",
            "через (\\d+[.,]?\\d*) секунду",
            "через (\\d+[.,]?\\d*) секунды"
        ],
        "in \\1 week": [
            "через (\\d+[.,]?\\d*) нед",
            "через (\\d+[.,]?\\d*) недели",
            "через (\\d+[.,]?\\d*) неделю"
        ],
        "in \\1 year": [
            "через (\\d+[.,]?\\d*) г",
            "через (\\d+[.,]?\\d*) год",
            "через (\\d+[.,]?\\d*) года"
        ]
    },
    "locale_specific": {
        "ru-BY": {
            "name": "ru-BY"
        },
        "ru-KG": {
            "name": "ru-KG"
        },
        "ru-KZ": {
            "name": "ru-KZ"
        },
        "ru-MD": {
            "name": "ru-MD"
        },
        "ru-UA": {
            "name": "ru-UA",
            "am": [
                "am"
            ],
            "pm": [
                "pm"
            ]
        }
    },
    "skip": [
        "в",
        "во",
        "и",
        "около",
        "примерно",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "назад"
    ],
    "in": [
        "в течение",
        "спустя",
        "через"
    ],
    "simplifications": [
        {
            "од(на|ну|ни|ной|ин)": "1"
        },
        {
            "дв(а|е|ое|ух)": "2"
        },
        {
            "пар[ауы]": "2"
        },
        {
            "три": "3"
        },
        {
            "четыре": "4"
        },
        {
            "пять": "5"
        },
        {
            "шесть": "6"
        },
        {
            "семь": "7"
        },
        {
            "восемь": "8"
        },
        {
            "девять": "9"
        },
        {
            "десять": "10"
        },
        {
            "одиннадцать": "11"
        },
        {
            "двенадцать": "12"
        },
        {
            "пятнадцать": "15"
        },
        {
            "двадцать": "20"
        },
        {
            "тридцать": "30"
        },
        {
            "сорок": "40"
        },
        {
            "пятьдесят": "50"
        },
        {
            "несколько секунд": "44 секунды"
        },
        {
            "полчаса": "30 минут"
        },
        {
            "полгода": "6 месяцев"
        },
        {
            "полтора часа": "90 минут"
        },
        {
            "полтора года": "18 месяцев"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)секунд[уы]|(?<=[^\\d]\\s+|^)секунду(?=(\\s+назад)))": "1 секунду"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)минут[уы]|(?<=[^\\d]\\s+|^)минуту(?=(\\s+назад)))": "1 минуту"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)часа?|(?<=[^\\d]\\s+|^)час(?=(\\s+назад)))": "1 час"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)(день|дня)|(?<=[^\\d]\\s+|^)день(?=(\\s+назад)))": "1 день"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)сут(ки|ок)|(?<=[^\\d]\\s+|^)сутки(?=(\\s+назад)))": "1 сутки"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)недел[юи]|(?<=[^\\d]\\s+|^)неделю(?=(\\s+назад)))": "1 неделю"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)месяца?|(?<=[^\\d]\\s+|^)месяц(?=(\\s+назад)))": "1 месяц"
        },
        {
            "((?<=(через|спустя|в течение)\\s+)года?|(?<=[^\\d]\\s+|^)год(?=(\\s+назад)))": "1 год"
        }
    ]
}



info = {
    "name": "rof",
    "date_order": "DMY",
    "january": [
        "mweri wa kwanza"
    ],
    "february": [
        "mweri wa kaili"
    ],
    "march": [
        "mweri wa katatu"
    ],
    "april": [
        "mweri wa kaana"
    ],
    "may": [
        "mweri wa tanu"
    ],
    "june": [
        "mweri wa sita"
    ],
    "july": [
        "mweri wa saba"
    ],
    "august": [
        "mweri wa nane"
    ],
    "september": [
        "mweri wa tisa"
    ],
    "october": [
        "mweri wa ikumi"
    ],
    "november": [
        "mweri wa ikumi na moja"
    ],
    "december": [
        "mweri wa ikumi na mbili"
    ],
    "monday": [
        "ijt",
        "ijumatatu"
    ],
    "tuesday": [
        "ijn",
        "ijumanne"
    ],
    "wednesday": [
        "ijtn",
        "ijumatano"
    ],
    "thursday": [
        "alh",
        "alhamisi"
    ],
    "friday": [
        "iju",
        "ijumaa"
    ],
    "saturday": [
        "ijm",
        "ijumamosi"
    ],
    "sunday": [
        "ijp",
        "ijumapili"
    ],
    "am": [
        "kang'ama"
    ],
    "pm": [
        "kingoto"
    ],
    "year": [
        "muaka"
    ],
    "month": [
        "mweri"
    ],
    "week": [
        "iwiki"
    ],
    "day": [
        "mfiri"
    ],
    "hour": [
        "isaa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "linu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "hiyo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ng'ama"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
